'use strict';

exports.__esModule = true;
exports.default = createCreateCreateObjectTypeMetadata;
// import generate from 'babel-generator'

function createCreateCreateObjectTypeMetadata(t, hasComment, depsId) {
    function isDepsId(prop) /*: boolean*/ {
        if (!prop.value || !prop.value.id) {
            // throw new Error(`isDepsId: not found value property in ${generate(prop).code}`)
            return false;
        }
        return prop.value.id.name === depsId;
    }

    return function createCreateObjectTypeMetadata(typeForAnnotation) {
        return function createObjectTypeMetadata(annotation) {
            var properties = annotation.properties;
            var types = annotation.types;
            if (!properties && types && types.length) {
                properties = types[types.length - 1].properties;
            }
            if (properties) {
                var props = [];
                var pr = properties.find(isDepsId);
                if (pr) {
                    if (pr.value.typeParameters) {
                        return typeForAnnotation(pr.value.typeParameters.params[0]);
                    }
                }

                for (var i = 0, l = properties.length; i < l; i++) {
                    var property = properties[i];
                    var key = property.key;
                    var value = property.value;

                    if (!key || !value) {
                        //     throw new Error(
                        // `createObjectTypeMetadata: Not found value property in ${generate(property).code}`
                        //     )
                        break;
                    }

                    if (hasComment(property, false)) {
                        break;
                    }

                    var val = typeForAnnotation(value);
                    if (val) {
                        props.push(t.objectProperty(t.identifier(key.name), val));
                    }
                    if (hasComment(property, true)) {
                        break;
                    }
                }
                return t.objectExpression(props);
            }
            return t.identifier('Object');
        };
    };
}
//# sourceMappingURL=createCreateCreateObjectTypeMetadata.js.map