'use strict';

exports.__esModule = true;
var getTypesInfo = {
    ImportDeclaration: function ImportDeclaration(path, state) {
        /* eslint-disable no-param-reassign */
        var node = path.node;
        var strPath = node.source.value;
        if (strPath === state.driverImport) {
            state.injectId = node.specifiers[0].local;
        }
        if (strPath === state.ambiantTypeCastImport) {
            state.ambiantTypeCast = path;
        } else {
            state.lastImportPath = path;
        }
        if (strPath === state.ambiantDepsImport) {
            state.depsId = node.specifiers[0].local.name;
        }
    },
    ClassDeclaration: function ClassDeclaration(path, state) {
        var node = path.node;
        state.externalClassNames.set(node.id.name, node.id.name);
    },
    'ImportSpecifier|ImportDefaultSpecifier': function ImportSpecifierImportDefaultSpecifier(path, state) {
        var node = path.node;
        var parent = path.parent;
        var importedName = node.type === 'ImportDefaultSpecifier' ? node.local.name : node.imported.name;

        state.externalClassNames.set(node.local.name, importedName);
        if (parent.importKind !== 'type') {
            return;
        }

        var token = state.getUniqueTypeName(parent.source.value, importedName);

        state.externalTypeNames.set(node.local.name, token);
    },
    ExportSpecifier: function ExportSpecifier(path, state) {
        var node = path.node;
        state.exportNames.set(node.local.name, node.exported.name);
    },
    'ExportNamedDeclaration|ExportDefaultDeclaration': function ExportNamedDeclarationExportDefaultDeclaration(path, state) {
        var node = path.node;
        var declaration = node.declaration;
        if (declaration) {
            var id = declaration.id || declaration;
            state.exportNames.set(id.name, id.name);
        }
    },
    TypeAlias: function TypeAlias(path, state) {
        var node = path.node;
        var parent = path.parent;
        state.externalClassNames.set(node.id.name, node.id.name);
        if (parent.type !== 'ExportNamedDeclaration') {
            state.internalTypes.set(node.id.name, node.right);
            return;
        }
        var token = state.getUniqueTypeName('', node.id.name);

        state.externalTypeNames.set(node.id.name, token);
    }
};

exports.default = getTypesInfo;
//# sourceMappingURL=getTypesInfo.js.map